==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-angular-core";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { typeCast, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let AreaSeries = /*@__PURE__*/ (() => {
    class AreaSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.zh = null;
            this.zh = new CategoryLineRasterizer();
            this.ab = AreaSeries.$;
            this.y0 = 0;
        }
        bc() {
            return new AreaSeries();
        }
        cd() {
            return new AreaSeriesView(this);
        }
        vy() {
            return 1;
        }
        cj() {
            if (this.ck == 0) {
                return 2;
            }
            return super.cj();
        }
        o2(a) {
            super.o2(a);
            this.zg = a;
        }
        get_ea() {
            return true;
        }
        get_d9() {
            return true;
        }
        preferredCategoryMode(a) {
            return this.y0;
        }
        f5(a, b) {
            let c = this.tj(this.to(a), true, false);
            if (this.y7(a, c, b)) {
                return true;
            }
            if (this.f4(a, b)) {
                return true;
            }
            if (this.uf(a, b)) {
                return true;
            }
            return false;
        }
        nk(a, b) {
            super.nk(a, b);
            let c = b;
            c.de();
        }
        w7(a, b) {
            super.w7(a, b);
            let c = b.cu.d;
            let d = typeCast(AreaSeriesView.$, b);
            let e = a.f;
            let f = this.getEffectiveViewport1(d);
            this.vw.a2(this, this.wg(), runOn(this, this.vh), this.wp(b), this.wq(b));
            let g = false;
            let h = this.vw.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                let i = new ScalerParams(0, b.by, b.bx, this.yx.ch, f);
                this.w3(e, -1, this.valueColumn.count, this.yx, i, b.q);
            }
            let j = d.dq;
            let k = d.dr;
            let l = d.ds;
            let m = d.dt;
            this.vw.ad(j, true, false, true, true);
            this.vw.ad(k, true, false, true, true);
            this.vw.ad(l, false, true, false, false);
            this.vw.ad(m, false, true, false, false);
            if (b.cy(a)) {
                d.dg(e.count, e, true, c, this.hk, (n, o, p, q, r) => this.yd(n, a.f.count, b), this.unknownValuePlotting, e.count == 1 ? null : this.xg(e, e.count - 1, b.bx, b.by, true));
                b.c1(a);
            }
            let n = this.fetchYAxis();
            l._opacity = this.vw.j * this.hg;
            m._opacity = 0.5 * this.vw.j * this.hg;
        }
        pa(a, b, c, d) {
            super.pa(a, b, c, d);
            switch (b) {
                case AreaSeries.$$p[0]:
                    this.vt.m = this.unknownValuePlotting == 0;
                    this.pr(false);
                    this.om();
                    break;
            }
        }
        get useHighMarkerFidelity() {
            return this.wk;
        }
    }
    AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    AreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::zj', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return AreaSeries;
})();
/**
 * @hidden
 */
export let AreaSeriesView = /*@__PURE__*/ (() => {
    class AreaSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.dd = null;
            this.dl = new Path();
            this.dn = new Path();
            this.dm = new Path();
            this.dp = new Path();
            this.dh = new Path();
            this.dj = new Path();
            this.di = new Path();
            this.dk = new Path();
            this.dd = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.dd.uc = Defaults.e;
            }
        }
        get dq() {
            return this.dn;
        }
        get dr() {
            return this.dp;
        }
        get ds() {
            return this.dl;
        }
        get dt() {
            return this.dm;
        }
        de() {
            this.dl.an = null;
            this.dm.an = null;
            this.dn.an = null;
            this.dp.an = null;
            this.as();
        }
        df(a, b, c, d, e, f, g) {
            this.dg(a, b, c, d, e, f, g, null);
        }
        dg(a, b, c, d, e, f, g, h) {
            this.dd.zh.a = typeCast(ISortingAxis_$type, this.cw.fetchXAxis()) !== null ? true : false;
            this.dd.zh.j(this.dl, this.dn, this.dm, this.dp, a, b, c, d, e, f, g, h);
            this.as();
        }
        be() {
            super.be();
            this.dh.an = this.dl.an;
            this.dj.an = this.dn.an;
            this.di.an = this.dm.an;
            this.dk.an = this.dp.an;
            let a = this.br();
            this.dh._fill = a;
            this.dh._opacity = 1;
            this.di._fill = a;
            this.di._opacity = 1;
            this.dj._stroke = a;
            this.dj.ad = this.e.hl + 3;
            this.dk._stroke = a;
            this.dk.ad = this.e.hl + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (b) {
                a.t(this.dh);
                a.t(this.di);
                a.t(this.dj);
                a.t(this.dk);
            }
            else {
                a.t(this.dl);
                a.t(this.dm);
                a.t(this.dn);
                a.t(this.dp);
            }
        }
        an(a) {
            super.an(a);
            this.e.a5.exportPathData(a, this.dn, "lowerShape", ["Lower"]);
            this.e.a5.exportPathData(a, this.dp, "upperShape", ["Upper", "Main"]);
            this.e.a5.exportPathData(a, this.dm, "translucentShape", ["Translucent"]);
            this.e.a5.exportPathData(a, this.dl, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s8 = a;
            this.e.is = 5;
            this.e.it = 1;
            this.e.iu = -3;
        }
    }
    AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
    return AreaSeriesView;
})();

==> igniteui-angular-charts-18.0.0.tgz: package/esm2015/lib/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-angular-core";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { typeCast, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let AreaSeries = /*@__PURE__*/ (() => {
    class AreaSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.aav = null;
            this.aav = new CategoryLineRasterizer();
            this.ab = AreaSeries.$;
            this.aae = 0;
        }
        bb() {
            return new AreaSeries();
        }
        ci() {
            return new AreaSeriesView(this);
        }
        xc() {
            return 1;
        }
        co() {
            if (this.cp == 0) {
                return 2;
            }
            return super.co();
        }
        px(a) {
            super.px(a);
            this.aau = a;
        }
        get_eg() {
            return true;
        }
        get_ef() {
            return true;
        }
        preferredCategoryMode(a) {
            return this.aae;
        }
        gf(a, b) {
            let c = this.uu(this.uz(a), true, false);
            if (this.aal(a, c, b)) {
                return true;
            }
            if (this.ge(a, b)) {
                return true;
            }
            if (this.vs(a, b)) {
                return true;
            }
            return false;
        }
        n7(a, b) {
            super.n7(a, b);
            let c = b;
            c.de();
        }
        yl(a, b) {
            super.yl(a, b);
            let c = b.cu.d;
            let d = typeCast(AreaSeriesView.$, b);
            let e = a.f;
            let f = this.getEffectiveViewport1(d);
            this.xa.a2(this, this.xu(), runOn(this, this.wv), this.x3(b), this.x4(b));
            let g = false;
            let h = this.xa.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                let i = new ScalerParams(0, b.by, b.bx, this.aab.ch, f);
                this.yh(e, -1, this.valueColumn.count, this.aab, i, b.q, -1);
            }
            let j = d.dq;
            let k = d.dr;
            let l = d.ds;
            let m = d.dt;
            this.xa.ad(j, true, false, true, true);
            this.xa.ad(k, true, false, true, true);
            this.xa.ad(l, false, true, false, false);
            this.xa.ad(m, false, true, false, false);
            if (b.cy(a)) {
                d.dg(e.count, e, true, c, this.hu, (n, o, p, q, r) => this.zr(n, a.f.count, b), this.unknownValuePlotting, e.count == 1 ? null : this.yu(e, e.count - 1, b.bx, b.by, true));
                b.c1(a);
            }
            let n = this.fetchYAxis();
            l._opacity = this.xa.j * this.hq;
            m._opacity = 0.5 * this.xa.j * this.hq;
        }
        p5(a, b, c, d) {
            super.p5(a, b, c, d);
            switch (b) {
                case AreaSeries.$$p[0]:
                    this.w7.m = this.unknownValuePlotting == 0;
                    this.qm(false);
                    this.ph();
                    break;
            }
        }
        get useHighMarkerFidelity() {
            return this.xy;
        }
    }
    AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    AreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::aax', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return AreaSeries;
})();
/**
 * @hidden
 */
export let AreaSeriesView = /*@__PURE__*/ (() => {
    class AreaSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.dd = null;
            this.dl = new Path();
            this.dn = new Path();
            this.dm = new Path();
            this.dp = new Path();
            this.dh = new Path();
            this.dj = new Path();
            this.di = new Path();
            this.dk = new Path();
            this.dd = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.dd.vp = Defaults.e;
            }
        }
        get dq() {
            return this.dn;
        }
        get dr() {
            return this.dp;
        }
        get ds() {
            return this.dl;
        }
        get dt() {
            return this.dm;
        }
        de() {
            this.dl.an = null;
            this.dm.an = null;
            this.dn.an = null;
            this.dp.an = null;
            this.as();
        }
        df(a, b, c, d, e, f, g) {
            this.dg(a, b, c, d, e, f, g, null);
        }
        dg(a, b, c, d, e, f, g, h) {
            this.dd.aav.a = typeCast(ISortingAxis_$type, this.cw.fetchXAxis()) !== null ? true : false;
            this.dd.aav.j(this.dl, this.dn, this.dm, this.dp, a, b, c, d, e, f, g, h);
            this.as();
        }
        be() {
            super.be();
            this.dh.an = this.dl.an;
            this.dj.an = this.dn.an;
            this.di.an = this.dm.an;
            this.dk.an = this.dp.an;
            let a = this.br();
            this.dh._fill = a;
            this.dh._opacity = 1;
            this.di._fill = a;
            this.di._opacity = 1;
            this.dj._stroke = a;
            this.dj.ad = this.e.hv + 3;
            this.dk._stroke = a;
            this.dk.ad = this.e.hv + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (b) {
                a.t(this.dh);
                a.t(this.di);
                a.t(this.dj);
                a.t(this.dk);
            }
            else {
                a.t(this.dl);
                a.t(this.dm);
                a.t(this.dn);
                a.t(this.dp);
            }
        }
        an(a) {
            super.an(a);
            this.e.a4.exportPathData(a, this.dn, "lowerShape", ["Lower"]);
            this.e.a4.exportPathData(a, this.dp, "upperShape", ["Upper", "Main"]);
            this.e.a4.exportPathData(a, this.dm, "translucentShape", ["Translucent"]);
            this.e.a4.exportPathData(a, this.dl, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.uj = a;
            this.e.i2 = 5;
            this.e.i3 = 1;
            this.e.i4 = -3;
        }
    }
    AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
    return AreaSeriesView;
})();
